#version 330 core
out vec4 FragColor;

uniform vec3 lightColour, objectColour;
uniform vec3 lightPosition, viewPosition;

in vec3 FragmentPos;
in vec3 Normal;

void main()
{
	float ambientStrength = 0.1;
	vec3 ambientLight = lightColour * ambientStrength;

	vec3 normal = normalize(Normal);
	vec3 lightDir = normalize(lightPosition - FragmentPos);
	float diff = max(dot(normal, lightDir), 0.0);
	vec3 diffuseLight = diff * lightColour;

	float specularStrength = 0.5;
	vec3 viewDir = normalize(viewPosition - FragmentPos);
	vec3 reflectDir = reflect(-lightDir, normal);
	float spec = pow(max(dot(viewDir, reflectDir), 0.0), 32); // The exponent (here 32) is the shininess of the specular highlight
	vec3 specularLight = specularStrength * spec * lightColour;

	vec3 result = (ambientLight + diffuseLight + specularLight) * objectColour;
	FragColor = vec4(result, 1.0);
} 